{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2016-2020 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}

{% extends "invenio_communities/base.html" %}

{%- block javascript %}
  {{ super() }}
  {{ webpack['invenio-communities-request.js'] }}
{%- endblock javascript %}


{%- block page_body %}
{%- set form_config = {"community": community, "membership": membership, "token": token} %}

<div
  id="app"
  data-form-config='{{ form_config | tojson }}'>
</div>

{%- endblock page_body %}


