{% set invitation_request = notification.context.request %}
{% set receiver = invitation_request.receiver %}
{% set community = invitation_request.created_by %}
{% set request_id = invitation_request.id %}

{% set community_title = community.metadata.title %}
{% set message = notification.context.message | safe if notification.context.message else '' %}
{% set role = notification.context.role %}

{# TODO: use request.links.self_html when issue issue is resolved: https://github.com/inveniosoftware/invenio-rdm-records/issues/1327 #}
{% set request_link = "{ui}/me/requests/{id}".format(
    ui=config.SITE_UI_URL, id=request_id
    )
%}

{%- block subject -%}
  {{ _("New invitation to join community '{community_title}' as '{role}'.").format(community_title=community_title, role=role) }}
{%- endblock subject -%}

{%- block html_body -%}
<p>
    {{ _("You have been invited to join community '{community_title}' as '{role}'.").format(community_title=community_title, role=role) }}
</p>

{%- if message %}
<p>
    {{ _("Invitation message:") }}
    {{ message }}
</p>
{%- endif %}

<a href="{{ request_link }}" class="button"> {{ _("Check out the invitation") }}</a>
{%- endblock html_body %}

{%- block plain_body -%}
{{ _("You have been invited to join community '{community_title}' as '{role}'.").format(community_title=community_title, role=role) }}

{%- if message %}
    {{ _("Invitation message:") }}
    {{ message }}
{%- endif %}

{{ _("Check out the invitation:") }} {{ request_link }}
{%- endblock plain_body %}

{# Markdown for Slack/Mattermost/chat #}
{%- block md_body -%}
{{ _("You have been invited to join community *{community_title}* as *{role}*.").format(community_title=community_title, role=role) }}

{%- if message %}
    {{ _("Invitation message:") }}
    {{ message }}
{%- endif %}

[{{ _("Check out the invitation") }}]({{ request_link }})
{%- endblock md_body %}
